==> percona-xtrabackup_8.0.35-30.orig.tar.gz: percona-xtrabackup-8.0.35-30/storage/ndb/src/kernel/vm/ThreadConfig.hpp <==
/*
   Copyright (c) 2003, 2023, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef ThreadConfig_H
#define ThreadConfig_H

#include <kernel_types.h>
#include <NodeState.hpp>
#include <portlib/NdbThread.h>

#define JAM_FILE_ID 231


class ThreadConfig
{
public:
  ThreadConfig();
  ~ThreadConfig();
  void init(void);

  void ipControlLoop(NdbThread*);

  int doStart(NodeState::StartLevel startLevel);
  void scanZeroTimeQueue();
private:

  void scanTimeQueue();
};

#undef JAM_FILE_ID

#endif // ThreadConfig_H

==> percona-xtrabackup-84_8.4.0-4.orig.tar.gz: percona-xtrabackup-8.4.0-4/storage/ndb/src/kernel/vm/ThreadConfig.hpp <==
/*
   Copyright (c) 2003, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef ThreadConfig_H
#define ThreadConfig_H

#include <kernel_types.h>
#include <portlib/NdbThread.h>
#include <NodeState.hpp>

#define JAM_FILE_ID 231

class ThreadConfig {
 public:
  ThreadConfig();
  ~ThreadConfig();
  void init(void);

  void ipControlLoop(NdbThread *);

  int doStart(NodeState::StartLevel startLevel);
  void scanZeroTimeQueue();

 private:
  void scanTimeQueue();
};

#undef JAM_FILE_ID

#endif  // ThreadConfig_H
